package com.sun.java.swing.plaf.motif;

import java.awt.Component;
import java.awt.Dimension;
import javax.swing.JDesktopPane;
import java.awt.Point;
import java.awt.Container;
import javax.swing.JInternalFrame;
import java.awt.Rectangle;
import javax.swing.SwingUtilities;
import javax.swing.JLayeredPane;
import javax.swing.plaf.UIResource;
import java.io.Serializable;
import javax.swing.DefaultDesktopManager;
import java.awt.Color;
import java.awt.Graphics;
import java.awt.Insets;
import javax.swing.plaf.ComponentUI;
import javax.swing.JComponent;
import javax.swing.plaf.basic.BasicDesktopPaneUI;

public class MotifDesktopPaneUI extends BasicDesktopPaneUI
{
    public static ComponentUI createUI(JComponent component) {
        return new MotifDesktopPaneUI();
    }
    
    public MotifDesktopPaneUI() {
    }
    
    @Override
    protected void installDesktopManager() {
        this.desktopManager = this.desktop.getDesktopManager();
        if (this.desktopManager == null) {
            this.desktopManager = new MotifDesktopPaneUI.MotifDesktopManager();
            this.desktop.setDesktopManager(this.desktopManager);
            ((MotifDesktopPaneUI.MotifDesktopManager)this.desktopManager).adjustIcons(this.desktop);
        }
    }
    
    public Insets getInsets(JComponent component) {
        return new Insets(0, 0, 0, 0);
    }
    
    private class DragPane extends JComponent
    {
        @Override
        public void paint(Graphics graphics) {
            graphics.setColor(Color.darkGray);
            graphics.drawRect(0, 0, this.getWidth() - 1, this.getHeight() - 1);
        }
    }
    
    private class MotifDesktopManager extends DefaultDesktopManager implements Serializable, UIResource
    {
        JComponent dragPane;
        boolean usingDragPane;
        private transient JLayeredPane layeredPaneForDragPane;
        int iconWidth;
        int iconHeight;
        
        private MotifDesktopManager() {
            this.usingDragPane = false;
        }
        
        @Override
        public void setBoundsForFrame(JComponent component, int n, int n2, int n3, int n4) {
            if (!this.usingDragPane) {
                int n5 = component.getWidth() != n3 || component.getHeight() != n4;
                Rectangle bounds2 = component.getBounds();
                component.setBounds(n, n2, n3, n4);
                SwingUtilities.computeUnion(n, n2, n3, n4, bounds2);
                component.getParent().repaint(bounds2.x, bounds2.y, bounds2.width, bounds2.height);
                if (!(n5 == 0)) {
                    component.validate();
                }
            }
            else {
                Rectangle bounds = this.dragPane.getBounds();
                this.dragPane.setBounds(n, n2, n3, n4);
                SwingUtilities.computeUnion(n, n2, n3, n4, bounds);
                this.dragPane.getParent().repaint(bounds.x, bounds.y, bounds.width, bounds.height);
            }
        }
        
        @Override
        public void beginDraggingFrame(JComponent component) {
            this.usingDragPane = false;
            if ((component.getParent() instanceof JLayeredPane)) {
                if (this.dragPane == null) {
                    this.dragPane = new MotifDesktopPaneUI.DragPane();
                }
                (this.layeredPaneForDragPane = (JLayeredPane)component.getParent()).setLayer(this.dragPane, Integer.MAX_VALUE);
                this.dragPane.setBounds(component.getX(), component.getY(), component.getWidth(), component.getHeight());
                this.layeredPaneForDragPane.add(this.dragPane);
                this.usingDragPane = true;
            }
        }
        
        @Override
        public void dragFrame(JComponent component, int n, int n2) {
            this.setBoundsForFrame(component, n, n2, component.getWidth(), component.getHeight());
        }
        
        @Override
        public void endDraggingFrame(JComponent component) {
            if (this.usingDragPane) {
                this.layeredPaneForDragPane.remove(this.dragPane);
                this.usingDragPane = false;
                if ((component instanceof JInternalFrame)) {
                    this.setBoundsForFrame(component, this.dragPane.getX(), this.dragPane.getY(), this.dragPane.getWidth(), this.dragPane.getHeight());
                }
                else if ((component instanceof JInternalFrame.JDesktopIcon)) {
                    this.adjustBoundsForIcon((JInternalFrame.JDesktopIcon)component, this.dragPane.getX(), this.dragPane.getY());
                }
            }
        }
        
        @Override
        public void beginResizingFrame(JComponent component, int n) {
            this.usingDragPane = false;
            if ((component.getParent() instanceof JLayeredPane)) {
                if (this.dragPane == null) {
                    this.dragPane = new MotifDesktopPaneUI.DragPane();
                }
                JLayeredPane layeredPane = (JLayeredPane)component.getParent();
                layeredPane.setLayer(this.dragPane, Integer.MAX_VALUE);
                this.dragPane.setBounds(component.getX(), component.getY(), component.getWidth(), component.getHeight());
                layeredPane.add(this.dragPane);
                this.usingDragPane = true;
            }
        }
        
        @Override
        public void resizeFrame(JComponent component, int n, int n2, int n3, int n4) {
            this.setBoundsForFrame(component, n, n2, n3, n4);
        }
        
        @Override
        public void endResizingFrame(JComponent component) {
            if (this.usingDragPane) {
                ((Container)component.getParent()).remove(this.dragPane);
                this.usingDragPane = false;
                this.setBoundsForFrame(component, this.dragPane.getX(), this.dragPane.getY(), this.dragPane.getWidth(), this.dragPane.getHeight());
            }
        }
        
        @Override
        public void iconifyFrame(JInternalFrame f) {
            JInternalFrame.JDesktopIcon desktopIcon = f.getDesktopIcon();
            Point location = desktopIcon.getLocation();
            this.adjustBoundsForIcon(desktopIcon, location.x, location.y);
            super.iconifyFrame(f);
        }
        
        protected void adjustIcons(JDesktopPane desktopPane) {
            Dimension preferredSize = new JInternalFrame.JDesktopIcon(new JInternalFrame()).getPreferredSize();
            this.iconWidth = preferredSize.width;
            this.iconHeight = preferredSize.height;
            JInternalFrame[] allFrames = desktopPane.getAllFrames();
            for (int i = 0; i < allFrames.length; ++i) {
                JInternalFrame.JDesktopIcon desktopIcon = allFrames[i].getDesktopIcon();
                Point location = desktopIcon.getLocation();
                this.adjustBoundsForIcon(desktopIcon, location.x, location.y);
            }
        }
        
        protected void adjustBoundsForIcon(JInternalFrame.JDesktopIcon desktopIcon, int n, int n2) {
            JDesktopPane desktopPane = desktopIcon.getDesktopPane();
            int height = desktopPane.getHeight();
            int iconWidth = this.iconWidth;
            int iconHeight = this.iconHeight;
            desktopPane.repaint(n, n2, iconWidth, iconHeight);
            n = ((n < 0) ? 0 : n);
            n2 = ((n2 < 0) ? 0 : n2);
            n2 = ((n2 >= height) ? (height - 1) : n2);
            int n3 = n / iconWidth * iconWidth;
            int n4 = height % iconHeight;
            int n5 = (n2 - n4) / iconHeight * iconHeight + n4;
            int n6 = n - n3;
            int n7 = n2 - n5;
            for (n = ((n6 < iconWidth / 2) ? n3 : (n3 + iconWidth)), n2 = ((n7 < iconHeight / 2) ? n5 : ((n5 + iconHeight < height) ? (n5 + iconHeight) : n5)); this.getIconAt(desktopPane, desktopIcon, n, n2) != null; n += iconWidth) {}
            if (n > desktopPane.getWidth()) {
                return;
            }
            if (desktopIcon.getParent() != null) {
                this.setBoundsForFrame(desktopIcon, n, n2, iconWidth, iconHeight);
            }
            else {
                desktopIcon.setLocation(n, n2);
            }
            return;
        }
        
        protected JInternalFrame.JDesktopIcon getIconAt(JDesktopPane desktopPane, JInternalFrame.JDesktopIcon desktopIcon, int n, int n2) {
            Component[] components = desktopPane.getComponents();
            for (int i = 0; i < components.length; ++i) {
                Component component = components[i];
                if (component instanceof JInternalFrame.JDesktopIcon && component != desktopIcon) {
                    Point location = component.getLocation();
                    if (location.x == n && location.y == n2) {
                        return (JInternalFrame.JDesktopIcon)component;
                    }
                }
            }
            return null;
        }
    }
}
